A Python library for FedaPay's API.

## Requirements

Python 3.10 and later.

## Setup

You can install this package by using the pip tool and installing:

```
$ pip install fedapay
```

## Setting up a Fedapay Account

You can sign up for a FedaPay account at <https://fedapay.com>.

## Using the FedaPay API

Please see <https://docs.fedapay.com/development/api> for up-to-date documentation.
